Bias Correction
================
This module computes bias corrections for the Maximum Likelihood Estimation (MLE) of cluster size distributions in stationary time series.

Overview
--------

The `biascorrection` module provides tools for estimating probabilities of cluster sizes, calculating related functions like \( \Upsilon \) and \( \Pi \), and finding roots for bias correction.

Functions
---------

The ``pbar`` Function
----------------------
.. autofunction:: xtremes.biascorrection.pbar

The ``pbar_dbm_fast`` Function
------------------------------
.. autofunction:: xtremes.biascorrection.pbar_dbm_fast

The ``hat_pis`` Function
------------------------
.. autofunction:: xtremes.biascorrection.hat_pis

The ``convolve_probabilities`` Function
---------------------------------------
.. autofunction:: xtremes.biascorrection.convolve_probabilities

The ``hat_frakp`` Function
--------------------------
.. autofunction:: xtremes.biascorrection.hat_frakp

The ``ups`` Function
--------------------
.. autofunction:: xtremes.biascorrection.ups

The ``ups_d`` Function
----------------------
.. autofunction:: xtremes.biascorrection.ups_d

The ``Pi`` Function
-------------------
.. autofunction:: xtremes.biascorrection.Pi

The ``varpi`` Function
----------------------
.. autofunction:: xtremes.biascorrection.varpi
